@@ -144,6 +144,44 @@ class OrderedSet(MutableSet):
         doc=set.union.__doc__)
 
 
+class frozendict(dict):
+    """An immutable, hashable dictionary."""
+
+    @classmethod
+    def fromkeys(cls, iterable, value=None):
+        """Overwrite :meth:`dict.fromkeys`."""
+        return cls(dict.fromkeys(iterable, value))
+
+    def __hash__(self):
+        if not hasattr(self, "_hash"):
+            self._hash = hash(tuple(sorted(self.items())))
+
+        return self._hash
+
+    def __str__(self):
+        return dict.__repr__(self)
+
+    def __repr__(self):
+        return "{}({})".format(self.__class__.__name__, self)
+
+    @property
+    def _modify(self, *args, **kwargs):
+        raise AttributeError(
+            "Cannot modify a {}.".format(self.__class__.__name__))
+
+    __delitem__ = _modify
+    __setitem__ = _modify
+    clear = _modify
+    pop = _modify
+    popitem = _modify
+    setdefault = _modify
+    update = _modify
+
+    def copy(self):
+        """Since :class:`frozendict` are immutable, returns self."""
+        return self
+
+
 class DetailedType:
     """Container for a pair of Python class and subtype.
 
@@ -272,6 +310,27 @@ class RecordTree(object):
                 return cls._flatten(path[:index] + thing + path[index+1:])
         return path
 
+    @classmethod
+    def _freeze(cls, value):
+        """Make a label or value hashable."""
+        if isinstance(value, list):
+            newValue = tuple(value)
+        elif isinstance(value, set):
+            newValue = frozenset(value)
+        elif isinstance(value, dict):
+            newValue = frozendict(value)
+        else:
+            newValue = value
+
+        try:
+            hash(newValue)
+        except Exception as error:
+            raise TypeError(
+                "Failed to freeze {} to a hashable type: Hashing {} gives: {}"
+                .format(value, newValue, error))
+
+        return newValue
+
     @staticmethod
     def _keyval_iterator(recordsOrDict):
         if isinstance(recordsOrDict, dict):
@@ -286,7 +345,7 @@ class RecordTree(object):
         else:
             return recordsOrDict
 
-    def __init__(self, recordsOrDict=(), addValues=False):
+    def __init__(self, recordsOrDict=(), addValues=False, freeze=True):
         """Construct a :class:`RecordTree`.
 
         :param recordsOrDict:
@@ -302,6 +361,9 @@ class RecordTree(object):
             values of zero are not stored in the tree.
         :type addValues:
             bool or list(tuple)
+
+        :param bool freeze:
+            Whether to transform mutable labels and values into hashable ones.
         """
         self._tree = self._NodeDict()
 
@@ -318,6 +380,10 @@ class RecordTree(object):
             path = self._flatten(path)
             node = self._tree
 
+            if freeze:
+                path = tuple(self._freeze(thing) for thing in path)
+                value = self._freeze(value)
+
             if value is not self.NONE and _add_values_at(path):
                 if value == 0:
                     # Do not add a value equal to zero.
