@@ -590,9 +590,10 @@ class QuadraticExpression(Expression):
         n = Q.size[0]
 
         # Define a sequence of small numbers for perturbation.
+        # TODO: These numbers are empirical; find worst case values.
         spread   = [abs(v) for v in Q.V if v]
-        minEps   = 2 * min(spread) * sys.float_info.epsilon
-        maxEps   = 2 * max(spread) * sys.float_info.epsilon
+        minEps   = 1 * min(spread) * sys.float_info.epsilon
+        maxEps   = n * max(spread) * sys.float_info.epsilon
         epsilons = set([0.0])
         for i in range(PSD_PERTURBATIONS):
             epsilons.add(minEps + i * (maxEps - minEps) / PSD_PERTURBATIONS)
