@@ -1,7 +1,7 @@
 # coding: utf-8
 
 # ------------------------------------------------------------------------------
-# Copyright (C) 2019 Maximilian Stahlberg
+# Copyright (C) 2019-2020 Maximilian Stahlberg
 #
 # This file is part of PICOS.
 #
@@ -26,6 +26,7 @@
 # ------------------------------------------------------------------------------
 
 import fnmatch
+import types
 
 from ..apidoc import api_end, api_start
 from ..solvers import all_solvers
@@ -377,6 +378,26 @@ OPTIONS = [
         :func:`solve <picos.Problem.solve>`.
         """),
 
+    ("cvxopt_kktsolver", (str, types.FunctionType), "ldl", """
+        The KKT solver used by CVXOPT internally.
+
+        See `CVXOPT's guide on exploiting structure
+        <https://cvxopt.org/userguide/coneprog.html#exploiting-structure>`_.
+
+        :obj:`None` denotes CVXOPT's default KKT solver.
+        """, None),
+
+    ("cvxopt_kktreg", float, 1e-9, """
+        The KKT solver regularization term used by CVXOPT internally.
+
+        This is an undocumented feature of CVXOPT, see `here
+        <https://github.com/cvxopt/cvxopt/issues/36#issuecomment-125165634>`_.
+
+        End of 2020, this option only affected the LDL KKT solver.
+
+        :obj:`None` denotes CVXOPT's default value.
+        """, None),
+
     ("gurobi_params", dict, {}, """
         A dictionary of Gurobi parameters to be set after general options are
         passed and before the search is started.
@@ -482,20 +503,27 @@ class Option(object):
         return "\n".join(line[i:].rstrip() for line in lines[first:last+1])
 
     def _set_value(self, value):
-        if value is not None and type(value) is not self.argType:
-            try:
-                value = self.argType(value)
-            except Exception:
-                raise TypeError("Failed to convert argument '{}' to option '{}'"
-                    " to type '{}'.".format(
-                    value, self.name, self.argType.__name__))
+        if value is not None and not isinstance(value, self.argType):
+            if isinstance(self.argType, type):
+                try:
+                    value = self.argType(value)
+                except Exception:
+                    raise TypeError("Failed to convert argument {} to option "
+                        "'{}' to type {}.".format(
+                        repr(value), self.name, self.argType.__name__))
+            else:
+                assert isinstance(self.argType, (tuple, list))
+                assert all(isinstance(t, type) for t in self.argType)
+                raise TypeError("Argument {} to option '{}' does not match "
+                    "permissible types {}.".format(repr(value), self.name,
+                    ", ".join(t.__name__ for t in self.argType)))
 
         try:
             if self.check is not None and not self.check(value):
                 raise ValueError()
         except Exception:
-            raise ValueError("The option '{}' does not accept the value '{}'."
-                .format(self.name, value))
+            raise ValueError("The option '{}' does not accept the value {}."
+                .format(self.name, repr(value)))
 
         self._value = value
 
@@ -534,7 +562,7 @@ def _tablerow(option, indentaion=0):
         "{}  * .. _option_{{0}}:\n\n"
         "{}    {{2}}"
     ).format(
-        *(4*(spaces,))).format(option.name, str(option.default),
+        *(4*(spaces,))).format(option.name, repr(option.default),
         "\n{}    ".format(spaces).join(option.description.splitlines()))
 
 
