@@ -283,7 +283,6 @@ class Problem(object):  # object inheritence necessary with Python 2.
     >>> C1 = P.add_constraint(X.sum <= 10)
     >>> C2 = P.add_constraint(X[0,0] == 1)
     >>> print(P)
-    ---------------------------------------
     Linear Program
       maximize tr(X)
       over
@@ -291,7 +290,6 @@ class Problem(object):  # object inheritence necessary with Python 2.
       subject to
         ∑(X) ≤ 10
         X[0,0] = 1
-    ---------------------------------------
     >>> # PICOS will select a suitable solver if you don't specify one.
     >>> solution = P.solve(solver = "cvxopt")
     >>> solution.claimedStatus
@@ -511,19 +509,20 @@ class Problem(object):  # object inheritence necessary with Python 2.
         :Example:
 
         >>> from picos import Problem, RealVariable
-        >>> x = RealVariable("x")
+        >>> x = RealVariable("x", 2)
         >>> P = Problem()
-        >>> P.set_objective("min", x**2)
+        >>> P.set_objective("min", abs(x)**2)
         >>> print(P.strategy)
         None
         >>> sol = P.solve(solver = "cvxopt")  # Creates a solution strategy.
         >>> print(P.strategy)
         1. ExtraOptions
         2. EpigraphReformulation
-        3. ConvexQuadraticToConicReformulation
+        3. SquaredNormToConicReformulation
         4. CVXOPTSolver
-        >>> P.add_constraint((x-2)**2 <= 1)  # Also convex quadratic.
-        <Convex Quadratic Constraint: (x - 2)² ≤ 1>
+        >>> # Add another constraint handled by SquaredNormToConicReformulation:
+        >>> P.add_constraint(abs(x - 2)**2 <= 1)
+        <Squared Norm Constraint: ‖x - [2]‖² ≤ 1>
         >>> P.strategy.valid(solver = "cvxopt")
         True
         >>> P.strategy.valid(solver = "glpk")
@@ -792,11 +791,7 @@ class Problem(object):  # object inheritence necessary with Python 2.
                 string += wrapper.fill(self._con_group_string(tuple(group)))
                 string += "\n"
 
-        # Enclose with lines.
-        width = max(len(line) for line in string.splitlines())
-        lines = "-"*width
-
-        return "{}\n{}{}".format(lines, string, lines)
+        return string.rstrip("\n")
 
     def __index__(self):
         return self._objective.__index__()
@@ -988,7 +983,6 @@ class Problem(object):  # object inheritence necessary with Python 2.
         >>> Cx=prob.add_list_of_constraints([(1|x[i]) < y[i] for i in range(5)])
         >>> Cy=prob.add_constraint(y>0)
         >>> print(prob)
-        --------------------------------------
         Linear Feasibility Problem
           find an assignment
           for
@@ -997,7 +991,6 @@ class Problem(object):  # object inheritence necessary with Python 2.
           subject to
             ∑(x[i]) ≤ y[i] ∀ i ∈ [0…4]
             y ≥ 0
-        --------------------------------------
         >>> # Retrieve the second constraint, indexed from zero:
         >>> prob.get_constraint(1)
         <1×1 Affine Constraint: ∑(x[1]) ≤ y[1]>
@@ -1081,7 +1074,6 @@ class Problem(object):  # object inheritence necessary with Python 2.
         >>> C2=prob.add_list_of_constraints([abs(w[i,j])<y[j] for (i,j) in IJ])
         >>> C3=prob.add_list_of_constraints([y[t] > y[t+1] for t in range(4)])
         >>> print(prob)
-        -----------------------------------------------------------
         Feasibility Problem
           find an assignment
           for
@@ -1092,7 +1084,6 @@ class Problem(object):  # object inheritence necessary with Python 2.
             uᵀ·x[i] ≤ y[i] ∀ i ∈ [0…4]
             ‖w[i,j]‖ ≤ y[j] ∀ (i,j) ∈ zip([1,2,4],[2,0,2])
             y[i] ≥ y[i+1] ∀ i ∈ [0…3]
-        -----------------------------------------------------------
         """
         if it is not None or indices is not None or key is not None:
             # Deprecated as of 2.0.
@@ -1272,13 +1263,11 @@ class Problem(object):  # object inheritence necessary with Python 2.
         >>> P = Problem()
         >>> P.set_objective("min", sum([var for var in vars]))
         >>> print(P)
-        -----------------------------------------------------------------------
         Linear Program
           minimize x + y[0] + y[1] + y[2] + y[3] + z[alice] + z[bob] + z[carol]
           over
             1×1 real variable x, y[0], y[1], y[2], y[3], z[alice], z[bob],
               z[carol]
-        -----------------------------------------------------------------------
         >>> # Retrieve the variables from the problem.
         >>> P.get_variable("x")
         <1×1 Real Variable: x>
@@ -1491,34 +1480,30 @@ class Problem(object):  # object inheritence necessary with Python 2.
         :Example:
 
         >>> from picos import Problem, RealVariable
-        >>> x = RealVariable("x")
+        >>> x = RealVariable("x", 2)
         >>> P = Problem()
-        >>> P.set_objective("min", x**2)
+        >>> P.set_objective("min", abs(x)**2)
         >>> Q = P.prepared(solver = "cvxopt")
         >>> print(Q.prepared_strategy)  # Show prepared reformulation steps.
         1. ExtraOptions
         2. EpigraphReformulation
-        3. ConvexQuadraticToConicReformulation
+        3. SquaredNormToConicReformulation
         4. CVXOPTSolver
         >>> Q.prepared_steps  # Check how many steps have been performed.
         3
         >>> print(P)
-        -----------------------
         Quadratic Program
-          minimize x²
+          minimize ‖x‖²
           over
-            1×1 real variable x
-        -----------------------
+            2×1 real variable x
         >>> print(Q)# doctest: +ELLIPSIS
-        -------------------------------------------------------------
         Second Order Cone Program
           minimize __..._t
           over
-            1×1 real variable __..._t, x
+            1×1 real variable __..._t
+            2×1 real variable x
           subject to
-            ‖quadroot(x²)‖² ≤ -(aff(x²) - __..._t) ∧ -(aff(x²) -
-              __..._t) ≥ 0
-        -------------------------------------------------------------
+            ‖fullroot(‖x‖²)‖² ≤ __..._t ∧ __..._t ≥ 0
         """
         from .strategy import Strategy
 
@@ -1707,7 +1692,11 @@ class Problem(object):  # object inheritence necessary with Python 2.
             endTime = time.time()
             solveTime = endTime - startTime
             searchTime = solution.searchTime
-            overhead = (solveTime - searchTime) / searchTime
+
+            if searchTime:
+                overhead = (solveTime - searchTime) / searchTime
+            else:
+                overhead = float("inf")
 
             if verbose:
                 print("Search {:.1e}s, solve {:.1e}s, overhead {:.0%}."
