@@ -157,9 +157,9 @@ class Solution:
     <infeasible primal solution (was feasible and claimed optimal) from cvxopt>
     """
 
-    def __init__(self, primals, duals={}, problem=None, solver="user",
+    def __init__(self, primals, duals=None, problem=None, solver="user",
             primalStatus=SS_UNKNOWN, dualStatus=SS_UNKNOWN,
-            problemStatus=PS_UNKNOWN, searchTime=0.0, info={},
+            problemStatus=PS_UNKNOWN, searchTime=0.0, info=None,
             vectorizedPrimals=False):
         """Create a solution to an optimization problem.
 
@@ -190,6 +190,12 @@ class Solution:
         from ..constraints import Constraint
         from .problem      import Problem
 
+        if duals is None:
+            duals = {}
+
+        if info is None:
+            info = {}
+
         # Be strict about the arguments as they are handed to the user.
         _check_type(primals, dict)
         _check_type(problem, None, Problem)
