@@ -361,7 +361,8 @@ class CVXOPTSolver(Solver):
 
         # Allow solving GPs that are not strictly feasible and work around
         # constraint matrix rank requirements.
-        cvxopt.solvers.options["kktreg"] = 1e-9
+        if self.ext.options.cvxopt_kktreg is not None:
+            cvxopt.solvers.options["kktreg"] = self.ext.options.cvxopt_kktreg
 
         # Handle unsupported options.
         self._handle_unsupported_options(
@@ -483,12 +484,16 @@ class CVXOPTSolver(Solver):
                     #       exception with infeasible/unbounded problems.
                     result = None
             else:
+                kwargs = {}
+                if self.ext.options.cvxopt_kktsolver is not None:
+                    kwargs["kktsolver"] = self.ext.options.cvxopt_kktsolver
+
                 if isGP:
                     result = cvxopt.solvers.gp(p["K"], p["F"], p["g"], p["Gl"],
-                        p["hl"], p["A"], p["b"], kktsolver="ldl")
+                        p["hl"], p["A"], p["b"], **kwargs)
                 else:
                     result = cvxopt.solvers.conelp(
-                        p["c"], G, h, dims, A, b, kktsolver="ldl")
+                        p["c"], G, h, dims, A, b, **kwargs)
 
         # Retrieve primals.
         primals = {}
